r23613 - gnucash/trunk/src/report - Use same name for dialog and menu related to preconfigured reports

Geert Janssens gjanssens at code.gnucash.org
Tue Dec 24 12:09:00 EST 2013


Author: gjanssens
Date: 2013-12-24 12:09:00 -0500 (Tue, 24 Dec 2013)
New Revision: 23613
Trac: http://svn.gnucash.org/trac/changeset/23613

Modified:
   gnucash/trunk/src/report/report-gnome/dialog-custom-report.glade
   gnucash/trunk/src/report/report-gnome/gnc-plugin-page-report.c
   gnucash/trunk/src/report/report-gnome/report-gnome.scm
   gnucash/trunk/src/report/report-system/report.scm
Log:
Use same name for dialog and menu related to preconfigured reports

Modified: gnucash/trunk/src/report/report-gnome/dialog-custom-report.glade
===================================================================
--- gnucash/trunk/src/report/report-gnome/dialog-custom-report.glade	2013-12-24 17:08:50 UTC (rev 23612)
+++ gnucash/trunk/src/report/report-gnome/dialog-custom-report.glade	2013-12-24 17:09:00 UTC (rev 23613)
@@ -4,7 +4,7 @@
   <!-- interface-naming-policy project-wide -->
   <object class="GtkDialog" id="custom_report_dialog">
     <property name="border_width">5</property>
-    <property name="title" translatable="yes">Preconfigured reports</property>
+    <property name="title" translatable="yes">Preconfigured Reports</property>
     <property name="window_position">center-on-parent</property>
     <property name="type_hint">dialog</property>
     <property name="skip_taskbar_hint">True</property>

Modified: gnucash/trunk/src/report/report-gnome/gnc-plugin-page-report.c
===================================================================
--- gnucash/trunk/src/report/report-gnome/report-gnome.scm	2013-12-24 17:08:50 UTC (rev 23612)
+++ gnucash/trunk/src/report/report-gnome/report-gnome.scm	2013-12-24 17:09:00 UTC (rev 23613)
@@ -111,9 +111,9 @@
 
   (gnc-add-scm-extension 
    (gnc:make-menu-item
-   (N_ "Custom Reports")
+   (N_ "Preconfigured Reports")
    "4d3dcdc8890b11df99dd94cddfd72085"
-   (N_ "Manage and run custom reports")
+   (N_ "Manage and run preconfigured reports")
    (list gnc:menuname-reports)
    (lambda (window)
      (gnc:spawn-custom-report-dialog window))))

Modified: gnucash/trunk/src/report/report-system/report.scm
===================================================================
--- gnucash/trunk/src/report/report-system/report.scm	2013-12-24 17:08:50 UTC (rev 23612)
+++ gnucash/trunk/src/report/report-system/report.scm	2013-12-24 17:09:00 UTC (rev 23613)
@@ -31,7 +31,7 @@
 ;; custom report: like a report-template, but saved with a different set
 ;;      of default options. A better name would probably be "preconfigured
 ;;      report" or something similar. These templates are managed by the
-;;      user via the "Custom Reports" menu item
+;;      user via the "Preconfigured Reports" menu item
 ;; report: an instantiation of a report-template (custom or otherwise). One
 ;;      specific instance of a template, loaded and configured by the user
 ;;      while the program is running.



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/report/report-gnome/gnc-plugin-page-report.c	2013-12-24 17:08:50 UTC (rev 23612)
+++ gnucash/trunk/src/report/report-gnome/gnc-plugin-page-report.c	2013-12-24 17:09:00 UTC (rev 23613)
@@ -1035,7 +1035,7 @@
     },
     {
         "ReportSaveAsAction", GTK_STOCK_SAVE_AS, N_("Save Report As..."), "<control><alt><shift>s",
-        N_("Add the current report's configuration to the `Custom Reports' menu. "
+        N_("Add the current report's configuration to the `Preconfigured Reports' menu. "
         "The report will be saved in the file ~/.gnucash/saved-reports-2.4. "),
         G_CALLBACK(gnc_plugin_page_report_save_as_cb)
     },
@@ -1476,7 +1476,7 @@
     save_func = scm_c_eval_string("gnc:report-to-template-new");
     rpt_id = scm_call_1(save_func, priv->cur_report);
 
     /* Open Custom Reports dialog to allow user to change the name */
     if (!scm_is_null (rpt_id))
     {
         GncPluginPage *reportPage = GNC_PLUGIN_PAGE (report);
@@ -1476,7 +1476,7 @@
     rpt_id = scm_call_1(save_func, priv->cur_report);
 
-    /* Open Custom Reports dialog to allow user to change the name */
+    /* Open Preconfigured Reports dialog to allow user to change the name */
     if (!scm_is_null (rpt_id))
     {

Modified: gnucash/trunk/src/report/report-gnome/report-gnome.scm
===================================================================